Learn R Programming

agfh (version 0.2.1)

RM_theta_var_moment_est: Moment-Based Estimator of Latent Model Variance

Description

Simple moment-based estimator of the variance of the latent model.

Usage

RM_theta_var_moment_est(X, Y, D)

Value

Returns a scalar estimate of variance.

Arguments

X

observed independent data to be analyzed

Y

observed dependent data to be analyzed

D

known precisions of response Y

Details

Simple moment-based estimator of the variance of the latent model.

Examples

Run this code
  X <- matrix(1:10, ncol=1)
  Y <- 2*X + rnorm(10, sd=1.1)
  D <- rep(1, 10)
  RM_theta_var_moment_est(X, Y, D)

Run the code above in your browser using DataLab