Learn R Programming

agfh (version 0.2.1)

adj_profile_likelihood_theta_var_maker: Maker Function: Adjusted Profile Likelihood of Latent Variance

Description

A maker function that returns a function. The returned function is the adjusted profile likelihood of the data for a given (latent) variance, from Yoshimori & Lahiri (2014).

Usage

adj_profile_likelihood_theta_var_maker(X, Y, D)

Value

Returns the adjusted profile likelihood as a function of the variance term in the latent model.

Arguments

X

observed independent data to be analyzed

Y

observed dependent data to be analyzed

D

known precisions of response Y

Examples

Run this code
  X <- matrix(1:10, ncol=1)
  Y <- 2*X + rnorm(10, sd=1.1)
  D <- rep(1, 10)
  adj.lik <- adj_profile_likelihood_theta_var_maker(X, Y, D)
  adj.lik(0.5)

Run the code above in your browser using DataLab