adj_resid_likelihood_theta_var_maker: Maker Function: Adjusted Residual Likelihood of Latent Variance
Description
A maker function that returns a function. The returned function is the adjusted residual likelihood of the data for a given (latent) variance, from Yoshimori & Lahiri (2014).
Usage
adj_resid_likelihood_theta_var_maker(X, Y, D)
Value
Returns the adjusted residual likelihood as a function of the variance term in the latent model.