Learn R Programming

agfh (version 0.2.1)

resid_likelihood_theta_var_maker: Maker Function: Residual Likelihood of Latent Variance

Description

A maker function that returns a function. The returned function is the (non-adjusted) residual likelihood of the data for a given (latent) variance, from Yoshimori & Lahiri (2014).

Usage

resid_likelihood_theta_var_maker(X, Y, D)

Value

Returns the (non-adjusted) residual likelihood as a function of the variance term in the latent model.

Arguments

X

observed independent data to be analyzed

Y

observed dependent data to be analyzed

D

known precisions of response Y

Examples

Run this code
  X <- matrix(1:10, ncol=1)
  Y <- 2*X + rnorm(10, sd=1.1)
  D <- rep(1, 10)
  resid.lik <- resid_likelihood_theta_var_maker(X, Y, D)
  resid.lik(0.5)

Run the code above in your browser using DataLab