adj_profile_likelihood_theta_var_maker: Maker Function: Adjusted Profile Likelihood of Latent Variance
Description
A maker function that returns a function. The returned function is the adjusted profile likelihood of the data for a given (latent) variance, from Yoshimori & Lahiri (2014).
Usage
adj_profile_likelihood_theta_var_maker(X, Y, D)
Value
Returns the adjusted profile likelihood as a function of the variance term in the latent model.