resid_likelihood_theta_var_maker: Maker Function: Residual Likelihood of Latent Variance
Description
A maker function that returns a function. The returned function is the (non-adjusted) residual likelihood of the data for a given (latent) variance, from Yoshimori & Lahiri (2014).
Usage
resid_likelihood_theta_var_maker(X, Y, D)
Value
Returns the (non-adjusted) residual likelihood as a function of the variance term in the latent model.